pub struct ClientToolAnswerOutcome {
pub answer: ChatbotConversationMessage,
pub turn_can_resume: bool,
}Expand description
What answering a client tool call left the suspended turn in.
Fields
answer: ChatbotConversationMessageturn_can_resume: boolWhether this was the last answer the turn was waiting for, and so the one answerer of a round of parallel calls that may resume it.